<?php

/**
 * @file
 * Webform component file for Mailjet Webform Subscription.
 */

/**
 * Implementation of _webform_defaults_component().
 */
function _webform_defaults_mailjet_checkbox() {
  return array(
    'name' => '',
    'form_key' => NULL,
    'pid' => 0,
    'weight' => 0,
    'value' => '',
    'mandatory' => 0,
    'extra' => array(
      'contact_list' => '',
      'private' => FALSE,

    ),
  );
}

/**
 * Implementation of _webform_theme_component().
 */
function _webform_theme_mailjet_checkbox() {
  return array(
    'webform_display_mailjet_checkbox' => array(
      'render element' => 'element',
    ),
  );
}

/**
 * Implementation of _webform_edit_component().
 */
function _webform_edit_mailjet_checkbox($component) {
  $options = array();
  if (variable_get('mailjet_active', FALSE) && variable_get('mailjet_username') && variable_get('mailjet_password')) {
    drupal_set_message(t('You need to have e-mail webform component added to your webform in order to make user able to subscribe to the Mailjet contact list'));
    $key = variable_get('mailjet_username', '');
    $secret_key = variable_get('mailjet_password', '');

    // Get All contact lists.
    $arguments = array();
    $url = 'https://api.mailjet.com/v3/REST/contactslist';
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array("Content-Type: application/json"));
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
    curl_setopt($ch, CURLOPT_USERAGENT, 'drupal-3.0');
    curl_setopt($ch, CURLOPT_USERPWD, $key . ':' . $secret_key);
    curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'GET');
    curl_setopt($ch, CURLOPT_POST, count($arguments));
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($arguments));
    $buffer = curl_exec($ch);
    $result = json_decode($buffer);
    if (isset($result->Count) && $result->Count > 0) {
      foreach ($result->Data as $list) {
        $options[$list->ID] = $list->Name;
      }
    }
  }
  else{
    drupal_set_message(t('You have to set Mailjet API keys <a href="@link">here</a> in order to get your contact lists', array('@link' => '/admin/config/system/mailjet/api')), 'warning');
  }

  $form = array();
  $form['extra']['contact_list'] = array(
    '#type' => 'select',
    '#title' => t('Select contact list'),
    '#options' => $options,
    '#empty_option' => t('Select'),
    '#empty_value' => 0,
    '#default_value' => $component['extra']['contact_list'],
    '#required' => TRUE,
  );
  return $form;
}

/**
 * Implementation of _webform_render_component().
 */
function _webform_render_mailjet_checkbox($component, $value = NULL, $filter = TRUE) {
  $node = isset($component['nid']) ? node_load($component['nid']) : NULL;
  $element['subscription_checkbox'] = array(
    '#type' => 'checkbox',
    '#title' => $component['name'],
    '#default_value' => $filter ? _webform_filter_values($component['value'], $node, NULL, NULL, FALSE) : $component['value'],
    '#required' => $component['mandatory'],
    '#weight' => $component['weight'],
    '#theme_wrappers' => array('webform_element'),
    '#webform_component' => $component,
  );
  if (isset($value) && is_array($value) && isset($value['subscription_checkbox'])) {
    $element['subscription_checkbox']['#default_value'] = $value['subscription_checkbox'];
  }

  // Storing contact list.
  $element['contact_list'] = array(
    '#type' => 'hidden',
    '#default_value' => $component['extra']['contact_list'],
  );
  $element['#weight'] = $component['weight'];
  return $element;
}

/**
 * Implementation of _webform_display_component().
 */
function _webform_display_mailjet_checkbox($component, $value, $format = 'html') {

  return array(
    '#title' => t('MailJet Subscription'),
    '#weight' => $component['weight'],
    '#theme' => 'webform_display_mailjet_checkbox',
    '#theme_wrappers' => $format == 'html' ? array('webform_element') : array('webform_element_text'),
    '#format' => $format,
    '#value' => isset($value) && is_array($value) && isset($value['subscription_checkbox']) ? $value['subscription_checkbox'] : '0',
    '#translatable' => array('title', 'contact_list'),
  );
}

/**
 * Implementation of _webform_display_component().
 */
function theme_webform_display_mailjet_checkbox($variables) {

  $element = $variables['element'];
  $value = $element['#value'];
  return $value !== '' ? $value : ' ';
}

/**
 * Implementation of _webform_table_component().
 */
function _webform_table_mailjet_checkbox($component, $value) {
  return isset($value) && is_array($value) && isset($value['subscription_checkbox']) ? $value['subscription_checkbox'] : '0';
}

/**
 * Implementation of _webform_csv_headers_component().
 */
function _webform_csv_headers_mailjet_checkbox($component, $export_options) {
  $header = array();
  $header[0] = $component['name'];
  return $header;
}

/**
 * Implementation of _webform_csv_data_component().
 */
function _webform_csv_data_mailjet_checkbox($component, $export_options, $value) {
  return isset($value) && is_array($value) && isset($value['subscription_checkbox']) ? $value['subscription_checkbox'] : '0';
}
